try{!function(){var n="undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{},e=(new n.Error).stack;e&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[e]="07dd71e0-da4f-4d87-8a39-439b4f2cc8ff",n._sentryDebugIdIdentifier="sentry-dbid-07dd71e0-da4f-4d87-8a39-439b4f2cc8ff")}()}catch(n){}!function(){try{("undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{}).SENTRY_RELEASE={id:"agent-cli@2026.04.28-e984b46"}}catch(n){}}(),exports.id=1832,exports.ids=[1832],exports.modules={"./src/commands/sandbox-config.ts":(n,e,o)=>{o.r(e),o.d(e,{handleSandboxDisable:()=>l,handleSandboxEnable:()=>c,handleSandboxReset:()=>b});var s=o("../shell-exec/dist/index.js"),t=o("./src/console-io.ts"),a=o("./src/sandbox-gate.ts"),i=o("./src/utils/sandbox-messages.ts"),d=function(n,e,o,s){return new(o||(o=Promise))((function(t,a){function i(n){try{r(s.next(n))}catch(n){a(n)}}function d(n){try{r(s.throw(n))}catch(n){a(n)}}function r(n){var e;n.done?t(n.value):(e=n.value,e instanceof o?e:new o((function(n){n(e)}))).then(i,d)}r((s=s.apply(n,e||[])).next())}))},r=function(n,e){var o={};for(var s in n)Object.prototype.hasOwnProperty.call(n,s)&&e.indexOf(s)<0&&(o[s]=n[s]);if(null!=n&&"function"==typeof Object.getOwnPropertySymbols){var t=0;for(s=Object.getOwnPropertySymbols(n);t<s.length;t++)e.indexOf(s[t])<0&&Object.prototype.propertyIsEnumerable.call(n,s[t])&&(o[s[t]]=n[s[t]])}return o};function c(n){return d(this,void 0,void 0,(function*(){(0,a.Y)()&&(0,s.K3)()||(yield n.transform((n=>Object.assign(Object.assign({},n),{sandbox:Object.assign(Object.assign({},n.sandbox),{mode:"disabled"})}))),(0,t.OT)(`Error: Sandbox is not available on this system. ${(0,i.l)()}.`),process.exit(1)),yield n.transform((n=>Object.assign(Object.assign({},n),{sandbox:Object.assign(Object.assign({},n.sandbox),{mode:"enabled"})}))),(0,t.OT)("✅ Sandbox mode enabled. Commands will now run in a sandbox environment."),(0,t.OT)("💡 Use 'agent sandbox disable' to switch back to allowlist mode."),process.exit(0)}))}function l(n){return d(this,void 0,void 0,(function*(){yield n.transform((n=>Object.assign(Object.assign({},n),{sandbox:Object.assign(Object.assign({},n.sandbox),{mode:"disabled"})}))),(0,t.OT)("✅ Sandbox mode disabled. Commands will now use allowlist mode (default)."),(0,t.OT)("💡 Use 'agent sandbox enable' to switch back to sandbox mode."),process.exit(0)}))}function b(n){return d(this,void 0,void 0,(function*(){yield n.transform((n=>{const{sandbox:e}=n,o=r(n,["sandbox"]);return Object.assign(Object.assign({},o),{showSandboxIntro:!0})})),(0,t.OT)("✅ Sandbox configuration reset. All sandbox-specific settings have been removed."),(0,t.OT)("💡 Use 'agent sandbox enable' to configure sandbox mode again."),process.exit(0)}))}},"./src/sandbox-gate.ts":(n,e,o)=>{o.d(e,{Y:()=>r});var s=o("./src/statsig.ts");const t="composer_sandbox_settings_visible",a="sandbox_force_disable_linux",i="sandbox_force_disable_win32";function d(n,e){return(0,s.mD)()?(0,s.QF)(n):e}function r(n="linux"){return!(!d(t,!0)||"linux"===n&&d(a,!1)||"win32"===n&&d(i,!0))}},"./src/utils/sandbox-messages.ts":(n,e,o)=>{o.d(e,{l:()=>t});var s=o("node:os");function t(){return function(){const n=function(){try{const n=s.release().match(/^(\d+)\.(\d+)/);if(n)return{major:parseInt(n[1],10),minor:parseInt(n[2],10)}}catch(n){}return null}();return!!n&&(n.major>6||6===n.major&&n.minor>=2)}()?"Sandbox failed to start, possibly due to AppArmor configuration. Visit https://cursor.com/docs/agent/terminal for troubleshooting steps":"Sandbox requires kernel v6.2 or later and may require additional AppArmor policies to be set. Visit https://cursor.com/docs/agent/terminal for troubleshooting steps"}}};